﻿using System;
using System.ComponentModel;
using System.Data;
using System.Windows.Forms;
using System.Drawing;
using LevelEditor;

namespace LevelEditorControls
{
    class MapPictureBox : PictureBox
    {
        int mouseX, mouseY;
        bool drawTile;

        public Map MapParent
        {
            get;
            set;
        }

        public Point TilePosition
        {
            get
            {
                return new Point(mouseX / MapParent.TileWidth, mouseY / MapParent.TileHeight);
            }
        }

        public Point TilePixelPosition
        {
            get
            {
                int drawX = mouseX - (mouseX % MapParent.TileWidth);
                int drawY = mouseY - (mouseY % MapParent.TileHeight);
                return new Point(drawX, drawY);
            }
        }

        public MapPictureBox()
        {
        }

        protected override void OnPaint(PaintEventArgs pe)
        {
            base.OnPaint(pe);

            if (drawTile && MapParent != null)
            {
                pe.Graphics.FillRectangle(Brushes.Red, new Rectangle(TilePixelPosition.X, TilePixelPosition.Y, MapParent.TileWidth, MapParent.TileHeight));
            }
        }

        protected override void OnMouseMove(MouseEventArgs e)
        {
            mouseX = e.X;
            mouseY = e.Y;
            base.OnMouseMove(e);
            this.Invalidate();
        }

        protected override void OnMouseEnter(EventArgs e)
        {
            base.OnMouseEnter(e);
            drawTile = true;
            this.Invalidate();
        }

        protected override void OnMouseLeave(EventArgs e)
        {
            base.OnMouseLeave(e);
            drawTile = false;
            this.Invalidate();
        }
    }
}